@@ -2,4 +2,4 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-from encrypti0n.v1 import *
\ No newline at end of file
+from encrypti0n.classes import *
