@@ -482,7 +482,7 @@ class Database(object):
 				#if old_format != new_format:
 				#	return r3sponse.error(f"Mismatching formats, old format: {old_format}, new format: {new_format}.")
 				if new_format == "dict":
-					new = Dictionary(old).check(default=default, save=False)
+					new = Dictionary(self.content).check(default=default, save=False)
 					print("NEW:",new,"VS",self.content,"=",new != Dictionary(self.content))
 					if new != Dictionary(self.content): do = True
 				elif new_format == "list":
